FaceAutoCaptureWidget class final

Face Auto Capture UI component (widget).

The widget with instructions for obtaining quality face images suitable for further processing.

Widget configuration

In order to configure the behaviour of FaceAutoCaptureWidget, use FaceAutoCaptureWidgetConfiguration and pass in to FaceAutoCaptureWidget.new. This is a required parameter.

Control the widget and consume outputs

As soon as the widget is created, the onCreated callback is called with the FaceAutoCaptureWidgetController parameter. Use the controller to control the Face Auto Capture process.

To start the Face Auto Capture process call the FaceAutoCaptureWidgetController.start method. You can start the process any time.

When the Face Auto Capture process finishes successfully, the result will be returned via the onFinished callback.

In case you want to force the capture event, call the FaceAutoCaptureWidgetController.requestCapture method. The most recent image will be returned via the onFinished callback asynchronously.

Call FaceAutoCaptureWidgetController.start method again in case you need to start over the Face Auto Capture process.

You can also call FaceAutoCaptureWidgetController.start method to stop and start over ongoing process as well.

In case you want to stop the Face Auto Capture process prematurely, call the FaceAutoCaptureWidgetController.stop method.

UI Customization

IDV Flutter SDK is wrapper around the native Android and iOS SDKs. If you want to customize the appearance of the widget on the Android platform, refer to the Android UI customization for detailed instructions. If you want to customize the appearance of the widget on the iOS platform use iosStyle.

Inheritance

Constructors

FaceAutoCaptureWidget({Key? key, required FaceAutoCaptureWidgetConfiguration configuration, IosFaceAutoCaptureWidgetStyle iosStyle = const IosFaceAutoCaptureWidgetStyle(), OnFaceAutoCaptureCreatedCallback? onCreated, OnFaceAutoCaptureUiStateUpdatedCallback? onUiStateUpdated, OnFaceAutoCaptureFinishedCallback? onFinished, OnFaceAutoCaptureNoCameraPermissionCallback? onNoCameraPermission})
Create a new widget with the given configuration, iosStyle and callbacks.
const

Properties

configuration FaceAutoCaptureWidgetConfiguration
Configuration of the Face Auto Capture component.
final
hashCode int
The hash code for this object.
no setterinherited
iosStyle IosFaceAutoCaptureWidgetStyle
Style of the Face Auto Capture component. Default value is IosFaceAutoCaptureWidgetStyle. Only valid for iOS, it is ignored on Android.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCreated OnFaceAutoCaptureCreatedCallback?
Called when the widget is created.
final
onFinished OnFaceAutoCaptureFinishedCallback?
Called only once for the whole process, when the final face image candidate has been chosen. Once this callback is called, the whole process is considered to be over.
final
onNoCameraPermission OnFaceAutoCaptureNoCameraPermissionCallback?
Called when camera permission was not granted.
final
onUiStateUpdated OnFaceAutoCaptureUiStateUpdatedCallback?
Called when a camera image is processed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited