FaceAutoCaptureWidgetConfiguration class final
Configuration for the Face Auto Capture UI component (FaceAutoCaptureWidget).
- Annotations
Constructors
- FaceAutoCaptureWidgetConfiguration({dynamic base, Placeholder placeholder = const VisiblePlaceholder(type: PlaceholderType.circle), bool isDetectionLayerVisible = false})
- Create an instance.
Properties
- base ↔ BaseFaceAutoCaptureWidgetConfiguration
-
Base configuration, see BaseFaceAutoCaptureWidgetConfiguration.
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDetectionLayerVisible → bool
-
Whether detection UI layer (tracking rectangle) is visible. Default value is
false.final - placeholder → Placeholder
-
Placeholder. Default value is VisiblePlaceholder.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited