MagnifEyeLivenessWidgetConfiguration class final
Configuration for the MagnifEye Liveness UI component (MagnifEyeLivenessWidget).
- Annotations
Constructors
- MagnifEyeLivenessWidgetConfiguration({dynamic common, dynamic camera, dynamic faceLibraryComponent, bool isDetectionLayerVisible = false})
- Create an instance.
Properties
- camera ↔ CameraConfiguration
-
Configuration for components utilizing a camera. Default value is CameraConfiguration
with
facingset to CameraFacing.front.latefinal - common ↔ CommonConfiguration
-
Common configuration for all components. Default value is CommonConfiguration.
latefinal
- faceLibraryComponent ↔ FaceLibraryComponentConfiguration
-
Configuration for face library components. Default value is FaceLibraryComponentConfiguration
with
faceSizeRatioIntervalset to[0.1, 0.3].latefinal - hashCode → int
-
The hash code for this object.
no setterinherited
- isDetectionLayerVisible → bool
-
Whether detection UI layer (tracking rectangle) is visible. Default value is
false.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited